@@ -19,23 +19,21 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
  *
  * Author: Tom Schoonjans <Tom.Schoonjans@gmail.com>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
-#ifndef __PEAS_UTILS_OSX_H__
-#define __PEAS_UTILS_OSX_H__
+#pragma once
 
 #include <glib.h>
 
 G_BEGIN_DECLS
 
-gchar *peas_dirs_os_x_get_bundle_resource_dir (void);
-gchar *peas_dirs_os_x_get_resource_dir        (const gchar *subdir,
-                                               const gchar *default_dir);
-gchar *peas_dirs_os_x_get_data_dir            (void);
-gchar *peas_dirs_os_x_get_lib_dir             (void);
-gchar *peas_dirs_os_x_get_locale_dir          (void);
-void   peas_open_url_osx                      (const gchar *uri);
+char *peas_dirs_os_x_get_bundle_resource_dir (void);
+char *peas_dirs_os_x_get_resource_dir        (const char *subdir,
+                                              const char *default_dir);
+char *peas_dirs_os_x_get_data_dir            (void);
+char *peas_dirs_os_x_get_lib_dir             (void);
+char *peas_dirs_os_x_get_locale_dir          (void);
+void  peas_open_url_osx                      (const char *uri);
 
 G_END_DECLS
-
-#endif /* __PEAS_UTILS_OSX_H__ */
-
