@@ -17,12 +17,13 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __INTROSPECTION_PREREQUISITE_H__
-#define __INTROSPECTION_PREREQUISITE_H__
+#pragma once
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include "../../testing-util/peas-test-common.h"
 
@@ -55,5 +56,3 @@ PEAS_TEST_EXPORT
 GType        introspection_prerequisite_get_type         (void) G_GNUC_CONST;
 
 G_END_DECLS
-
-#endif /* __INTROSPECTION_PREREQUISITE_H__ */
